# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.service_unavailable_error import ServiceUnavailableError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.cascade import Cascade
from ..types.configure_apple_pay_organization_api_response import ConfigureApplePayOrganizationApiResponse
from ..types.configure_apple_paypoint_api_response import ConfigureApplePaypointApiResponse
from ..types.configure_google_paypoint_api_response import ConfigureGooglePaypointApiResponse
from ..types.entry import Entry
from ..types.is_enabled import IsEnabled
from ..types.organization_id import OrganizationId
from ..types.payabli_api_response import PayabliApiResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawWalletClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def configure_apple_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ConfigureApplePayOrganizationApiResponse]:
        """
        Configure and activate Apple Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ConfigureApplePayOrganizationApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            "Wallet/applepay/configure-organization",
            method="POST",
            json={
                "cascade": cascade,
                "isEnabled": is_enabled,
                "orgId": org_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePayOrganizationApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePayOrganizationApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def configure_apple_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ConfigureApplePaypointApiResponse]:
        """
        Configure and activate Apple Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Apple Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ConfigureApplePaypointApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            "Wallet/applepay/configure-paypoint",
            method="POST",
            json={
                "entry": entry,
                "isEnabled": is_enabled,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePaypointApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePaypointApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def configure_google_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ConfigureApplePayOrganizationApiResponse]:
        """
        Configure and activate Google Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ConfigureApplePayOrganizationApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            "Wallet/googlepay/configure-organization",
            method="POST",
            json={
                "cascade": cascade,
                "isEnabled": is_enabled,
                "orgId": org_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePayOrganizationApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePayOrganizationApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def configure_google_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[ConfigureGooglePaypointApiResponse]:
        """
        Configure and activate Google Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Google Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ConfigureGooglePaypointApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            "Wallet/googlepay/configure-paypoint",
            method="POST",
            json={
                "entry": entry,
                "isEnabled": is_enabled,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureGooglePaypointApiResponse,
                    parse_obj_as(
                        type_=ConfigureGooglePaypointApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawWalletClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def configure_apple_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ConfigureApplePayOrganizationApiResponse]:
        """
        Configure and activate Apple Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ConfigureApplePayOrganizationApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            "Wallet/applepay/configure-organization",
            method="POST",
            json={
                "cascade": cascade,
                "isEnabled": is_enabled,
                "orgId": org_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePayOrganizationApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePayOrganizationApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def configure_apple_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ConfigureApplePaypointApiResponse]:
        """
        Configure and activate Apple Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Apple Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ConfigureApplePaypointApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            "Wallet/applepay/configure-paypoint",
            method="POST",
            json={
                "entry": entry,
                "isEnabled": is_enabled,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePaypointApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePaypointApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def configure_google_pay_organization(
        self,
        *,
        cascade: typing.Optional[Cascade] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        org_id: typing.Optional[OrganizationId] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ConfigureApplePayOrganizationApiResponse]:
        """
        Configure and activate Google Pay for a Payabli organization

        Parameters
        ----------
        cascade : typing.Optional[Cascade]

        is_enabled : typing.Optional[IsEnabled]

        org_id : typing.Optional[OrganizationId]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ConfigureApplePayOrganizationApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            "Wallet/googlepay/configure-organization",
            method="POST",
            json={
                "cascade": cascade,
                "isEnabled": is_enabled,
                "orgId": org_id,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureApplePayOrganizationApiResponse,
                    parse_obj_as(
                        type_=ConfigureApplePayOrganizationApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def configure_google_pay_paypoint(
        self,
        *,
        entry: typing.Optional[Entry] = OMIT,
        is_enabled: typing.Optional[IsEnabled] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[ConfigureGooglePaypointApiResponse]:
        """
        Configure and activate Google Pay for a Payabli paypoint

        Parameters
        ----------
        entry : typing.Optional[Entry]

        is_enabled : typing.Optional[IsEnabled]
            When `true`, Google Pay is enabled.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ConfigureGooglePaypointApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            "Wallet/googlepay/configure-paypoint",
            method="POST",
            json={
                "entry": entry,
                "isEnabled": is_enabled,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ConfigureGooglePaypointApiResponse,
                    parse_obj_as(
                        type_=ConfigureGooglePaypointApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AuthCapturePayoutResponse,
        AuthCapturePayoutResponseData,
        AuthorizePaymentMethod,
        AuthorizePayoutBody,
        CaptureAllOutResponse,
        CaptureAllOutResponseResponseDataItem,
        LotNumber,
        OperationResult,
        RequestOutAuthorizeInvoiceData,
        RequestOutAuthorizePaymentDetails,
        RequestOutAuthorizeVendorBillingData,
        RequestOutAuthorizeVendorData,
        RequestOutAuthorizeVendorDataOld,
        VCardGetResponse,
        VCardGetResponseAssociatedVendor,
        VCardGetResponseAssociatedVendorBillingData,
        VCardGetResponseAssociatedVendorSummary,
        VCardGetResponseContact,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AuthCapturePayoutResponse": ".types",
    "AuthCapturePayoutResponseData": ".types",
    "AuthorizePaymentMethod": ".types",
    "AuthorizePayoutBody": ".types",
    "CaptureAllOutResponse": ".types",
    "CaptureAllOutResponseResponseDataItem": ".types",
    "LotNumber": ".types",
    "OperationResult": ".types",
    "RequestOutAuthorizeInvoiceData": ".types",
    "RequestOutAuthorizePaymentDetails": ".types",
    "RequestOutAuthorizeVendorBillingData": ".types",
    "RequestOutAuthorizeVendorData": ".types",
    "RequestOutAuthorizeVendorDataOld": ".types",
    "VCardGetResponse": ".types",
    "VCardGetResponseAssociatedVendor": ".types",
    "VCardGetResponseAssociatedVendorBillingData": ".types",
    "VCardGetResponseAssociatedVendorSummary": ".types",
    "VCardGetResponseContact": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AuthCapturePayoutResponse",
    "AuthCapturePayoutResponseData",
    "AuthorizePaymentMethod",
    "AuthorizePayoutBody",
    "CaptureAllOutResponse",
    "CaptureAllOutResponseResponseDataItem",
    "LotNumber",
    "OperationResult",
    "RequestOutAuthorizeInvoiceData",
    "RequestOutAuthorizePaymentDetails",
    "RequestOutAuthorizeVendorBillingData",
    "RequestOutAuthorizeVendorData",
    "RequestOutAuthorizeVendorDataOld",
    "VCardGetResponse",
    "VCardGetResponseAssociatedVendor",
    "VCardGetResponseAssociatedVendorBillingData",
    "VCardGetResponseAssociatedVendorSummary",
    "VCardGetResponseContact",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .orgid import Orgid
from .template_code import TemplateCode
from .template_content import TemplateContent
from .template_name import TemplateName


class TemplateData(UniversalBaseModel):
    """
    Object containing the template's data.
    """

    org_id: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="orgId")] = pydantic.Field(
        default=None
    )
    """
    The ID of the organization the template belongs to. 
    """

    pricing_id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="pricingId")] = None
    template_code: typing_extensions.Annotated[typing.Optional[TemplateCode], FieldMetadata(alias="templateCode")] = (
        None
    )
    template_content: typing_extensions.Annotated[
        typing.Optional[TemplateContent], FieldMetadata(alias="templateContent")
    ] = None
    template_description: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="templateDescription")
    ] = pydantic.Field(default=None)
    """
    A description for the template.
    """

    template_name: typing_extensions.Annotated[typing.Optional[TemplateName], FieldMetadata(alias="templateName")] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class PushPayLinkRequestEmail(UniversalBaseModel):
    additional_emails: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="additionalEmails")
    ] = pydantic.Field(default=None)
    """
    List of additional email addresses you want to send the paylink to, formatted as an array. 
    Payment links and opt-in requests are sent to the customer email address on file, and additional 
    recipients can be specified here.
    """

    attach_file: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="attachFile")] = pydantic.Field(
        default=None
    )
    """
    When `true`, attaches a PDF version of the invoice to the email.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..core.request_options import RequestOptions
from ..errors.bad_request_error import BadRequestError
from ..errors.internal_server_error import InternalServerError
from ..errors.service_unavailable_error import ServiceUnavailableError
from ..errors.unauthorized_error import UnauthorizedError
from ..types.cloud_query_api_response import CloudQueryApiResponse
from ..types.idempotency_key import IdempotencyKey
from ..types.payabli_api_response import PayabliApiResponse
from .types.add_device_response import AddDeviceResponse
from .types.remove_device_response import RemoveDeviceResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawCloudClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def add_device(
        self,
        entry: str,
        *,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        description: typing.Optional[str] = OMIT,
        registration_code: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[AddDeviceResponse]:
        """
        Register a cloud device to an entrypoint. See [Devices Quickstart](/developers/developer-guides/devices-quickstart#devices-quickstart) for a complete guide.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        idempotency_key : typing.Optional[IdempotencyKey]

        description : typing.Optional[str]
            Description or name for the device. This can be anything, but Payabli recommends entering the name of the paypoint, or some other easy to identify descriptor. If you have several devices for one paypoint, you can give them descriptions like "Cashier 1" and "Cashier 2", or "Front Desk" and "Back Office"

        registration_code : typing.Optional[str]
            The device registration code or serial number, depending on the model.

            - Ingenico devices: This is the activation code that's displayed on the device screen during setup.

            - PAX A920 device: This code is the serial number on the back of the device.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[AddDeviceResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Cloud/register/{jsonable_encoder(entry)}",
            method="POST",
            json={
                "description": description,
                "registrationCode": registration_code,
            },
            headers={
                "content-type": "application/json",
                "idempotencyKey": str(idempotency_key) if idempotency_key is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AddDeviceResponse,
                    parse_obj_as(
                        type_=AddDeviceResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def history_device(
        self, device_id: str, entry: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[CloudQueryApiResponse]:
        """
        Retrieve the registration history for a device.

        Parameters
        ----------
        device_id : str
            ID of the cloud device.

        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CloudQueryApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Cloud/history/{jsonable_encoder(entry)}/{jsonable_encoder(device_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CloudQueryApiResponse,
                    parse_obj_as(
                        type_=CloudQueryApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def list_device(
        self,
        entry: str,
        *,
        force_refresh: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[CloudQueryApiResponse]:
        """
        Get a list of cloud devices registered to an entrypoint.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        force_refresh : typing.Optional[bool]
            When `true`, the request retrieves an updated list of devices from the processor instead of returning a cached list of devices.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[CloudQueryApiResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Cloud/list/{jsonable_encoder(entry)}",
            method="GET",
            params={
                "forceRefresh": force_refresh,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CloudQueryApiResponse,
                    parse_obj_as(
                        type_=CloudQueryApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def remove_device(
        self, device_id: str, entry: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[RemoveDeviceResponse]:
        """
        Remove a cloud device from an entrypoint.

        Parameters
        ----------
        device_id : str
            ID of the cloud device.

        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[RemoveDeviceResponse]
            Success
        """
        _response = self._client_wrapper.httpx_client.request(
            f"Cloud/register/{jsonable_encoder(entry)}/{jsonable_encoder(device_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RemoveDeviceResponse,
                    parse_obj_as(
                        type_=RemoveDeviceResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawCloudClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def add_device(
        self,
        entry: str,
        *,
        idempotency_key: typing.Optional[IdempotencyKey] = None,
        description: typing.Optional[str] = OMIT,
        registration_code: typing.Optional[str] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[AddDeviceResponse]:
        """
        Register a cloud device to an entrypoint. See [Devices Quickstart](/developers/developer-guides/devices-quickstart#devices-quickstart) for a complete guide.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        idempotency_key : typing.Optional[IdempotencyKey]

        description : typing.Optional[str]
            Description or name for the device. This can be anything, but Payabli recommends entering the name of the paypoint, or some other easy to identify descriptor. If you have several devices for one paypoint, you can give them descriptions like "Cashier 1" and "Cashier 2", or "Front Desk" and "Back Office"

        registration_code : typing.Optional[str]
            The device registration code or serial number, depending on the model.

            - Ingenico devices: This is the activation code that's displayed on the device screen during setup.

            - PAX A920 device: This code is the serial number on the back of the device.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[AddDeviceResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Cloud/register/{jsonable_encoder(entry)}",
            method="POST",
            json={
                "description": description,
                "registrationCode": registration_code,
            },
            headers={
                "content-type": "application/json",
                "idempotencyKey": str(idempotency_key) if idempotency_key is not None else None,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    AddDeviceResponse,
                    parse_obj_as(
                        type_=AddDeviceResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def history_device(
        self, device_id: str, entry: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[CloudQueryApiResponse]:
        """
        Retrieve the registration history for a device.

        Parameters
        ----------
        device_id : str
            ID of the cloud device.

        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CloudQueryApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Cloud/history/{jsonable_encoder(entry)}/{jsonable_encoder(device_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CloudQueryApiResponse,
                    parse_obj_as(
                        type_=CloudQueryApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def list_device(
        self,
        entry: str,
        *,
        force_refresh: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[CloudQueryApiResponse]:
        """
        Get a list of cloud devices registered to an entrypoint.

        Parameters
        ----------
        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        force_refresh : typing.Optional[bool]
            When `true`, the request retrieves an updated list of devices from the processor instead of returning a cached list of devices.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[CloudQueryApiResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Cloud/list/{jsonable_encoder(entry)}",
            method="GET",
            params={
                "forceRefresh": force_refresh,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    CloudQueryApiResponse,
                    parse_obj_as(
                        type_=CloudQueryApiResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def remove_device(
        self, device_id: str, entry: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[RemoveDeviceResponse]:
        """
        Remove a cloud device from an entrypoint.

        Parameters
        ----------
        device_id : str
            ID of the cloud device.

        entry : str
            The paypoint's entrypoint identifier. [Learn more](/api-reference/api-overview#entrypoint-vs-entry)

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[RemoveDeviceResponse]
            Success
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"Cloud/register/{jsonable_encoder(entry)}/{jsonable_encoder(device_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    RemoveDeviceResponse,
                    parse_obj_as(
                        type_=RemoveDeviceResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Optional[typing.Any],
                        parse_obj_as(
                            type_=typing.Optional[typing.Any],  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 503:
                raise ServiceUnavailableError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        PayabliApiResponse,
                        parse_obj_as(
                            type_=PayabliApiResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .card_types import CardTypes
from .pos_col import PosCol
from .pos_row import PosRow
from .read_only import ReadOnly
from .visible import Visible


class CardAcceptanceElement(UniversalBaseModel):
    types: typing.Optional[CardTypes] = None
    pos_col: typing_extensions.Annotated[typing.Optional[PosCol], FieldMetadata(alias="posCol")] = None
    pos_row: typing_extensions.Annotated[typing.Optional[PosRow], FieldMetadata(alias="posRow")] = None
    read_only: typing_extensions.Annotated[typing.Optional[ReadOnly], FieldMetadata(alias="readOnly")] = None
    value: typing.Optional[str] = None
    visible: typing.Optional[Visible] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .policy_id import PolicyId
from .under_writing_method import UnderWritingMethod


class UnderwritingData(UniversalBaseModel):
    """
    Underwriting data is used to manage risk orchestration in the boarding application lifecycle.
    """

    method: UnderWritingMethod
    policy_id: typing_extensions.Annotated[typing.Optional[PolicyId], FieldMetadata(alias="policyId")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class VCardGetResponseContact(UniversalBaseModel):
    """
    Contact information structure.
    """

    contact_name: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactName")] = (
        pydantic.Field(default=None)
    )
    """
    Name of the contact.
    """

    contact_email: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Email of the contact.
    """

    contact_title: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactTitle")] = (
        pydantic.Field(default=None)
    )
    """
    Title of the contact.
    """

    contact_phone: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="ContactPhone")] = (
        pydantic.Field(default=None)
    )
    """
    Phone number of the contact.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .contacts_field import ContactsField
from .created_at import CreatedAt
from .file_content import FileContent
from .instrument import Instrument
from .is_root import IsRoot
from .org_parent_id import OrgParentId
from .org_parent_name import OrgParentName
from .orgaddress import Orgaddress
from .organization_query_record_services_item import OrganizationQueryRecordServicesItem
from .orgcity import Orgcity
from .orgcountry import Orgcountry
from .orgentryname import Orgentryname
from .orgid import Orgid
from .orgidstring import Orgidstring
from .orgname import Orgname
from .orgstate import Orgstate
from .orgtimezone import Orgtimezone
from .orgtype import Orgtype
from .orgwebsite import Orgwebsite
from .orgzip import Orgzip
from .recipient_email_notification import RecipientEmailNotification
from .reply_to_email import ReplyToEmail
from .resumable import Resumable
from .summary_org import SummaryOrg
from .user_query_record import UserQueryRecord


class OrganizationQueryRecord(UniversalBaseModel):
    services: typing.Optional[typing.List[OrganizationQueryRecordServicesItem]] = None
    billing_info: typing_extensions.Annotated[typing.Optional[Instrument], FieldMetadata(alias="billingInfo")] = None
    contacts: typing.Optional[ContactsField] = None
    created_at: typing_extensions.Annotated[typing.Optional[CreatedAt], FieldMetadata(alias="createdAt")] = None
    has_billing: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="hasBilling")] = None
    has_residual: typing_extensions.Annotated[typing.Optional[bool], FieldMetadata(alias="hasResidual")] = None
    id_org: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="idOrg")] = None
    is_root: typing_extensions.Annotated[typing.Optional[IsRoot], FieldMetadata(alias="isRoot")] = None
    org_address: typing_extensions.Annotated[typing.Optional[Orgaddress], FieldMetadata(alias="orgAddress")] = None
    org_city: typing_extensions.Annotated[typing.Optional[Orgcity], FieldMetadata(alias="orgCity")] = None
    org_country: typing_extensions.Annotated[typing.Optional[Orgcountry], FieldMetadata(alias="orgCountry")] = None
    org_entry_name: typing_extensions.Annotated[typing.Optional[Orgentryname], FieldMetadata(alias="orgEntryName")] = (
        None
    )
    org_id: typing_extensions.Annotated[typing.Optional[Orgidstring], FieldMetadata(alias="orgId")] = None
    org_logo: typing_extensions.Annotated[typing.Optional[FileContent], FieldMetadata(alias="orgLogo")] = None
    org_name: typing_extensions.Annotated[typing.Optional[Orgname], FieldMetadata(alias="orgName")] = None
    org_parent_id: typing_extensions.Annotated[typing.Optional[OrgParentId], FieldMetadata(alias="orgParentId")] = None
    org_parent_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="orgParentName")
    ] = None
    org_state: typing_extensions.Annotated[typing.Optional[Orgstate], FieldMetadata(alias="orgState")] = None
    org_timezone: typing_extensions.Annotated[typing.Optional[Orgtimezone], FieldMetadata(alias="orgTimezone")] = None
    org_type: typing_extensions.Annotated[typing.Optional[Orgtype], FieldMetadata(alias="orgType")] = None
    org_website: typing_extensions.Annotated[typing.Optional[Orgwebsite], FieldMetadata(alias="orgWebsite")] = None
    org_zip: typing_extensions.Annotated[typing.Optional[Orgzip], FieldMetadata(alias="orgZip")] = None
    recipient_email_notification: typing_extensions.Annotated[
        typing.Optional[RecipientEmailNotification], FieldMetadata(alias="recipientEmailNotification")
    ] = None
    reply_to_email: typing_extensions.Annotated[typing.Optional[ReplyToEmail], FieldMetadata(alias="replyToEmail")] = (
        None
    )
    resumable: typing.Optional[Resumable] = None
    summary: typing.Optional[SummaryOrg] = None
    users: typing.Optional[typing.List[UserQueryRecord]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .annualrevenue import Annualrevenue
from .application_data_odp_contacts_item import ApplicationDataOdpContactsItem
from .application_data_odp_ownership_item import ApplicationDataOdpOwnershipItem
from .attachments import Attachments
from .baddress_1 import Baddress1
from .baddress_2 import Baddress2
from .bank_data import BankData
from .bcity import Bcity
from .bcountry import Bcountry
from .boarding_business_fax import BoardingBusinessFax
from .boarding_business_phone import BoardingBusinessPhone
from .bstate import Bstate
from .bsummary import Bsummary
from .busstartdate import Busstartdate
from .bzip import Bzip
from .dbaname import Dbaname
from .ein import Ein
from .email import Email
from .highticketamt import Highticketamt
from .legalname import Legalname
from .license import License
from .licensestate import Licensestate
from .maddress import Maddress
from .maddress_1 import Maddress1
from .mcc import Mcc
from .mcity import Mcity
from .mcountry import Mcountry
from .mstate import Mstate
from .mzip import Mzip
from .orgid import Orgid
from .own_type import OwnType
from .payout_average_monthly_volume import PayoutAverageMonthlyVolume
from .payout_average_ticket_limit import PayoutAverageTicketLimit
from .payout_credit_limit import PayoutCreditLimit
from .payout_high_ticket_amount import PayoutHighTicketAmount
from .recipient_email_notification import RecipientEmailNotification
from .rep_code import RepCode
from .rep_name import RepName
from .rep_office import RepOffice
from .resumable import Resumable
from .services import Services
from .signer_data_request import SignerDataRequest
from .taxfillname import Taxfillname
from .template_id import TemplateId
from .website import Website


class ApplicationDataOdp(UniversalBaseModel):
    services: typing.Optional[Services] = None
    annual_revenue: typing_extensions.Annotated[
        typing.Optional[Annualrevenue], FieldMetadata(alias="annualRevenue")
    ] = pydantic.Field(default=None)
    """
    Annual revenue amount. We recommend including this value.
    """

    attachments: typing.Optional[Attachments] = None
    baddress: typing.Optional[Baddress1] = None
    baddress_1: typing_extensions.Annotated[typing.Optional[Baddress2], FieldMetadata(alias="baddress1")] = None
    bank_data: typing_extensions.Annotated[typing.Optional[BankData], FieldMetadata(alias="bankData")] = None
    bcity: typing.Optional[Bcity] = None
    bcountry: typing.Optional[Bcountry] = None
    boarding_link_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="boardingLinkId")] = (
        pydantic.Field(default=None)
    )
    """
    Boarding link ID for the application. Either `templateId` or `boardingLinkId` are required.
    """

    bstate: typing.Optional[Bstate] = None
    bsummary: typing.Optional[Bsummary] = None
    btype: typing.Optional[OwnType] = None
    bzip: typing.Optional[Bzip] = None
    contacts: typing.Optional[typing.List[ApplicationDataOdpContactsItem]] = pydantic.Field(default=None)
    """
    List of contacts for the business.
    """

    dbaname: typing.Optional[Dbaname] = None
    ein: typing.Optional[Ein] = None
    faxnumber: typing.Optional[BoardingBusinessFax] = None
    highticketamt: typing.Optional[Highticketamt] = None
    legalname: typing.Optional[Legalname] = None
    license: typing.Optional[License] = None
    licstate: typing.Optional[Licensestate] = None
    maddress: typing.Optional[Maddress] = None
    maddress_1: typing_extensions.Annotated[typing.Optional[Maddress1], FieldMetadata(alias="maddress1")] = None
    mcc: typing.Optional[Mcc] = None
    mcity: typing.Optional[Mcity] = None
    mcountry: typing.Optional[Mcountry] = None
    mstate: typing.Optional[Mstate] = None
    mzip: typing.Optional[Mzip] = None
    org_id: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="orgId")] = None
    ownership: typing.Optional[typing.List[ApplicationDataOdpOwnershipItem]] = pydantic.Field(default=None)
    """
    List of Owners with at least a 25% ownership.
    """

    payout_average_monthly_volume: typing_extensions.Annotated[
        PayoutAverageMonthlyVolume, FieldMetadata(alias="payoutAverageMonthlyVolume")
    ]
    payout_average_ticket_amount: typing_extensions.Annotated[
        PayoutAverageTicketLimit, FieldMetadata(alias="payoutAverageTicketAmount")
    ]
    payout_credit_limit: typing_extensions.Annotated[PayoutCreditLimit, FieldMetadata(alias="payoutCreditLimit")]
    payout_high_ticket_amount: typing_extensions.Annotated[
        PayoutHighTicketAmount, FieldMetadata(alias="payoutHighTicketAmount")
    ]
    phonenumber: typing.Optional[BoardingBusinessPhone] = None
    recipient_email: typing_extensions.Annotated[typing.Optional[Email], FieldMetadata(alias="recipientEmail")] = (
        pydantic.Field(default=None)
    )
    """
    Email address for the applicant. This is used to send the applicant a boarding link.
    """

    recipient_email_notification: typing_extensions.Annotated[
        typing.Optional[RecipientEmailNotification], FieldMetadata(alias="recipientEmailNotification")
    ] = None
    resumable: typing.Optional[Resumable] = None
    signer: SignerDataRequest
    startdate: typing.Optional[Busstartdate] = None
    taxfillname: typing.Optional[Taxfillname] = None
    template_id: typing_extensions.Annotated[typing.Optional[TemplateId], FieldMetadata(alias="templateId")] = (
        pydantic.Field(default=None)
    )
    """
    The associated boarding template's ID in Payabli. Either `templateId` or `boardingLinkId` are required.
    """

    website: typing.Optional[Website] = None
    rep_code: typing_extensions.Annotated[typing.Optional[RepCode], FieldMetadata(alias="RepCode")] = None
    rep_name: typing_extensions.Annotated[typing.Optional[RepName], FieldMetadata(alias="RepName")] = None
    rep_office: typing_extensions.Annotated[typing.Optional[RepOffice], FieldMetadata(alias="RepOffice")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .avgmonthly import Avgmonthly
from .avgticketamt import Avgticketamt
from .baddress_1 import Baddress1
from .baddress_2 import Baddress2
from .bank_data import BankData
from .bcity import Bcity
from .bcountry import Bcountry
from .binperson import Binperson
from .binphone import Binphone
from .binweb import Binweb
from .boarding_id import BoardingId
from .bphone import Bphone
from .bstate import Bstate
from .bsummary import Bsummary
from .busstartdate import Busstartdate
from .bzip import Bzip
from .contacts_field import ContactsField
from .created_at import CreatedAt
from .dbaname import Dbaname
from .ein import Ein
from .external_paypoint_id import ExternalPaypointId
from .external_processor_information import ExternalProcessorInformation
from .highticketamt import Highticketamt
from .idpaypoint import Idpaypoint
from .last_modified import LastModified
from .legalname import Legalname
from .license import License
from .licensestate import Licensestate
from .maddress import Maddress
from .maddress_1 import Maddress1
from .mcity import Mcity
from .mcountry import Mcountry
from .mstate import Mstate
from .mzip import Mzip
from .org_parent_name import OrgParentName
from .orgid import Orgid
from .own_type import OwnType
from .ownership import Ownership
from .paypoint_entry_config import PaypointEntryConfig
from .paypoint_summary import PaypointSummary
from .paypointstatus import Paypointstatus
from .sales_code import SalesCode
from .services import Services
from .taxfillname import Taxfillname
from .template_id import TemplateId
from .timezone import Timezone
from .website import Website
from .whencharged import Whencharged
from .whendelivered import Whendelivered
from .whenprovided import Whenprovided
from .whenrefunded import Whenrefunded


class QueryEntrypointResponseRecordsItem(UniversalBaseModel):
    average_monthly_volume: typing_extensions.Annotated[
        typing.Optional[Avgmonthly], FieldMetadata(alias="AverageMonthlyVolume")
    ] = None
    average_ticket_amount: typing_extensions.Annotated[
        typing.Optional[Avgticketamt], FieldMetadata(alias="AverageTicketAmount")
    ] = None
    b_address_1: typing_extensions.Annotated[typing.Optional[Baddress1], FieldMetadata(alias="BAddress1")] = None
    b_address_2: typing_extensions.Annotated[typing.Optional[Baddress2], FieldMetadata(alias="BAddress2")] = None
    bank_data: typing_extensions.Annotated[typing.Optional[BankData], FieldMetadata(alias="BankData")] = None
    b_city: typing_extensions.Annotated[typing.Optional[Bcity], FieldMetadata(alias="BCity")] = None
    b_country: typing_extensions.Annotated[typing.Optional[Bcountry], FieldMetadata(alias="BCountry")] = None
    b_fax: typing_extensions.Annotated[typing.Optional[Bphone], FieldMetadata(alias="BFax")] = pydantic.Field(
        default=None
    )
    """
    The business's fax number.
    """

    bin_person: typing_extensions.Annotated[typing.Optional[Binperson], FieldMetadata(alias="BinPerson")] = None
    bin_phone: typing_extensions.Annotated[typing.Optional[Binphone], FieldMetadata(alias="BinPhone")] = None
    bin_web: typing_extensions.Annotated[typing.Optional[Binweb], FieldMetadata(alias="BinWeb")] = None
    boarding_id: typing_extensions.Annotated[typing.Optional[BoardingId], FieldMetadata(alias="BoardingId")] = None
    b_phone: typing_extensions.Annotated[typing.Optional[Bphone], FieldMetadata(alias="BPhone")] = None
    b_startdate: typing_extensions.Annotated[typing.Optional[Busstartdate], FieldMetadata(alias="BStartdate")] = None
    b_state: typing_extensions.Annotated[typing.Optional[Bstate], FieldMetadata(alias="BState")] = None
    b_summary: typing_extensions.Annotated[typing.Optional[Bsummary], FieldMetadata(alias="BSummary")] = None
    b_time_zone: typing_extensions.Annotated[typing.Optional[Timezone], FieldMetadata(alias="BTimeZone")] = None
    b_zip: typing_extensions.Annotated[typing.Optional[Bzip], FieldMetadata(alias="BZip")] = None
    contact_data: typing_extensions.Annotated[typing.Optional[ContactsField], FieldMetadata(alias="ContactData")] = None
    created_at: typing_extensions.Annotated[typing.Optional[CreatedAt], FieldMetadata(alias="CreatedAt")] = None
    dba_name: typing_extensions.Annotated[typing.Optional[Dbaname], FieldMetadata(alias="DbaName")] = None
    documents_ref: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="DocumentsRef")] = None
    ein: typing_extensions.Annotated[typing.Optional[Ein], FieldMetadata(alias="Ein")] = None
    entry_points: typing_extensions.Annotated[
        typing.Optional[typing.List[PaypointEntryConfig]], FieldMetadata(alias="EntryPoints")
    ] = None
    external_paypoint_id: typing_extensions.Annotated[
        typing.Optional[ExternalPaypointId], FieldMetadata(alias="externalPaypointID")
    ] = None
    external_processor_information: typing_extensions.Annotated[
        typing.Optional[ExternalProcessorInformation], FieldMetadata(alias="ExternalProcessorInformation")
    ] = None
    high_ticket_amount: typing_extensions.Annotated[
        typing.Optional[Highticketamt], FieldMetadata(alias="HighTicketAmount")
    ] = None
    id_paypoint: typing_extensions.Annotated[typing.Optional[Idpaypoint], FieldMetadata(alias="IdPaypoint")] = None
    last_modified: typing_extensions.Annotated[typing.Optional[LastModified], FieldMetadata(alias="LastModified")] = (
        None
    )
    legal_name: typing_extensions.Annotated[typing.Optional[Legalname], FieldMetadata(alias="LegalName")] = None
    license: typing_extensions.Annotated[typing.Optional[License], FieldMetadata(alias="License")] = None
    license_state: typing_extensions.Annotated[typing.Optional[Licensestate], FieldMetadata(alias="LicenseState")] = (
        None
    )
    m_address_1: typing_extensions.Annotated[typing.Optional[Maddress], FieldMetadata(alias="MAddress1")] = None
    m_address_2: typing_extensions.Annotated[typing.Optional[Maddress1], FieldMetadata(alias="MAddress2")] = None
    mccid: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="Mccid")] = None
    m_city: typing_extensions.Annotated[typing.Optional[Mcity], FieldMetadata(alias="MCity")] = None
    m_country: typing_extensions.Annotated[typing.Optional[Mcountry], FieldMetadata(alias="MCountry")] = None
    m_state: typing_extensions.Annotated[typing.Optional[Mstate], FieldMetadata(alias="MState")] = None
    m_zip: typing_extensions.Annotated[typing.Optional[Mzip], FieldMetadata(alias="MZip")] = None
    org_id: typing_extensions.Annotated[typing.Optional[Orgid], FieldMetadata(alias="OrgId")] = None
    org_parent_name: typing_extensions.Annotated[
        typing.Optional[OrgParentName], FieldMetadata(alias="OrgParentName")
    ] = None
    owner_data: typing_extensions.Annotated[typing.Optional[Ownership], FieldMetadata(alias="OwnerData")] = None
    own_type: typing_extensions.Annotated[typing.Optional[OwnType], FieldMetadata(alias="OwnType")] = None
    paypoint_status: typing_extensions.Annotated[
        typing.Optional[Paypointstatus], FieldMetadata(alias="PaypointStatus")
    ] = None
    sales_code: typing_extensions.Annotated[typing.Optional[SalesCode], FieldMetadata(alias="SalesCode")] = None
    service_data: typing_extensions.Annotated[typing.Optional[Services], FieldMetadata(alias="ServiceData")] = None
    summary: typing.Optional[PaypointSummary] = None
    taxfillname: typing_extensions.Annotated[typing.Optional[Taxfillname], FieldMetadata(alias="Taxfillname")] = None
    template_id: typing_extensions.Annotated[typing.Optional[TemplateId], FieldMetadata(alias="TemplateId")] = None
    website_address: typing_extensions.Annotated[typing.Optional[Website], FieldMetadata(alias="WebsiteAddress")] = (
        pydantic.Field(default=None)
    )
    """
    Business website.
    """

    whencharged: typing_extensions.Annotated[typing.Optional[Whencharged], FieldMetadata(alias="Whencharged")] = None
    whendelivered: typing_extensions.Annotated[typing.Optional[Whendelivered], FieldMetadata(alias="Whendelivered")] = (
        None
    )
    whenprovided: typing_extensions.Annotated[typing.Optional[Whenprovided], FieldMetadata(alias="Whenprovided")] = None
    whenrefund: typing_extensions.Annotated[typing.Optional[Whenrefunded], FieldMetadata(alias="Whenrefund")] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
import uuid

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class NotificationLog(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    The unique identifier for the notification.
    """

    org_id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="orgId")] = pydantic.Field(
        default=None
    )
    """
    The ID of the organization that the notification belongs to.
    """

    paypoint_id: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="paypointId")] = pydantic.Field(
        default=None
    )
    """
    The ID of the paypoint that the notification is related to.
    """

    notification_event: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="notificationEvent")] = (
        pydantic.Field(default=None)
    )
    """
    The event that triggered the notification.
    """

    target: typing.Optional[str] = pydantic.Field(default=None)
    """
    The target URL for the notification.
    """

    response_status: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="responseStatus")] = (
        pydantic.Field(default=None)
    )
    """
    The HTTP response status of the notification.
    """

    success: bool = pydantic.Field()
    """
    Indicates whether the notification was successful.
    """

    job_data: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="jobData")] = pydantic.Field(
        default=None
    )
    """
    Contains the body of the notification.
    """

    created_date: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdDate")] = pydantic.Field()
    """
    The date and time when the notification was created.
    """

    success_date: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="successDate")] = (
        pydantic.Field(default=None)
    )
    """
    The date and time when the notification was successfully delivered.
    """

    last_failed_date: typing_extensions.Annotated[
        typing.Optional[dt.datetime], FieldMetadata(alias="lastFailedDate")
    ] = pydantic.Field(default=None)
    """
    The date and time when the notification last failed.
    """

    is_in_progress: typing_extensions.Annotated[bool, FieldMetadata(alias="isInProgress")] = pydantic.Field()
    """
    Indicates whether the notification is currently in progress.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata
from .page_identifier import PageIdentifier


class BatchSummary(UniversalBaseModel):
    """
    Examples
    --------
    from payabli import BatchSummary

    BatchSummary(
        page_size=20,
        total_amount=0.0,
        total_net_amount=0.0,
        total_pages=411,
        total_records=8203,
    )
    """

    pageidentifier: typing.Optional[PageIdentifier] = None
    page_size: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="pageSize")] = pydantic.Field(
        default=None
    )
    """
    Number of records on each response page.
    """

    total_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalAmount")] = (
        pydantic.Field(default=None)
    )
    """
    Total amount for the records.
    """

    total_net_amount: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="totalNetAmount")] = (
        pydantic.Field(default=None)
    )
    """
    Total net amount for the records.
    """

    total_pages: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalPages")] = pydantic.Field(
        default=None
    )
    """
    Total number of pages in response.
    """

    total_records: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="totalRecords")] = (
        pydantic.Field(default=None)
    )
    """
    Total number of records in response.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
